#' inferCSN: Inferring Cell-Specific Gene Regulatory Network
#'
#' @description
#'  A method for inferring cell-specific gene regulatory network from single-cell sequencing data.
#'
#' @author Meng xu (Maintainer), \email{mengxu98@qq.com}
#'
#' @source \url{https://github.com/mengxu98/inferCSN}
#'
#' @docType package
#' @name inferCSN-package
"_PACKAGE"
